Update of /cvsroot/fink/experimental/beren12/finkinfo/base
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv21021

Added Files:
        debconf.info debconf.patch dpkg.info dpkg.patch tar.info 
Log Message:
essential updates

--- NEW FILE: dpkg.patch ---
diff -urN dpkg-1.10.21.orig/Makefile.conf.in dpkg-1.10.21/Makefile.conf.in
--- dpkg-1.10.21.orig/Makefile.conf.in  Sun Sep 14 08:43:49 2003
+++ dpkg-1.10.21/Makefile.conf.in       Wed Jun  2 22:18:56 2004
@@ -60,13 +60,13 @@
 
 CPPFLAGS               = @CPPFLAGS@
 LD                     = @LD@
-LDFLAGS                        = @LDFLAGS@ -L../lib -L../optlib
+LDFLAGS                        = @LDFLAGS@ -L../lib -L../optlib -framework 
CoreFoundation
 LIBS                   = @LIBS@ -ldpkg -lopt $(ZLIB_LIBS)
 
 RANLIB                 = @RANLIB@
 
 DEFS                   = @DEFS@ -D_GNU_SOURCE
-INCLUDE_CFLAGS         = -I$(top_srcdir)/include -I$(top_srcdir) -I$(srcdir) 
-I../include -I.. -I. -I$(top_srcdir)/optlib
+INCLUDE_CFLAGS         = -I$(top_srcdir)/include -I$(top_srcdir) -I$(srcdir) 
-I../include -I.. -I. -I$(top_srcdir)/optlib 
-F/System/Library/Frameworks/CoreFoundation.framework
 
 NLS_CFLAGS             = -DLOCALEDIR=\"$(localedir)\" -I$(top_srcdir)/intl 
-I../intl
 NLS_LIBS               = @INTLLIBS@ 
[...2399 lines suppressed...]
 and
-.B /usr/share/common-licenses/GPL
+.B @PREFIX@/share/common-licenses/GPL
 for details.
+Paths modified by Carsten Klapp to reflect fink distribution, December 2002.
diff -urN dpkg-1.10.21.orig/utils/Makefile.in dpkg-1.10.21/utils/Makefile.in
--- dpkg-1.10.21.orig/utils/Makefile.in Sun Aug 25 04:54:19 2002
+++ dpkg-1.10.21/utils/Makefile.in      Wed Jun  2 22:18:56 2004
@@ -72,9 +72,9 @@
        $(INSTALL_DATA) $(srcdir)/$(MD5_MANPAGES) $(DESTDIR)/$(man1dir)
 
 start-stop-daemon: $(SSD_OBJECTS) ../lib/libdpkg.a
-       $(CC) $(LDFLAGS) -o $@ $(SSD_OBJECTS) $(LIBS) $(SSD_LIBS)
+       $(CC) $(LDFLAGS) $(EXEFLAGS) -o $@ $(SSD_OBJECTS) $(LIBS) $(SSD_LIBS)
 
 md5sum-static: LDFLAGS += -static
 md5sum-static: ZLIB_LIBS = $(ZLIBS_LIBS_ALSO_STATIC)
 md5sum md5sum-static: $(MD5_OBJECTS) ../lib/libdpkg.a
-       $(CC) $(LDFLAGS) -o $@ $(MD5_OBJECTS) $(LIBS) $(NLS_LIBS)
+       $(CC) $(LDFLAGS) $(EXEFLAGS) -o $@ $(MD5_OBJECTS) $(LIBS) $(NLS_LIBS)

--- NEW FILE: debconf.patch ---
diff -ruN debconf-1.4.42/transition_db.pl debconf-1.4.42.new/transition_db.pl
--- debconf-1.4.42/transition_db.pl     Mon Sep 13 05:58:41 2004
+++ debconf-1.4.42.new/transition_db.pl Mon Jan 17 01:09:32 2005
@@ -6,7 +6,7 @@
 use Debconf::Question;
 use Debconf::Template;
 
-my $dir = shift || '/var/lib/debconf';
+my $dir = shift || '@FINKPREFIX@/var/lib/debconf';
 
 Debconf::Db->load;
 

--- NEW FILE: debconf.info ---
Package: debconf
Version: 1.4.42
Revision: 2
BuildDepends: html2text, findutils, libgettext3-dev
Depends: dialog, %n-english | %n-i18n
Type: perl
Source: mirror:debian:/pool/main/d/debconf/%n_%v.tar.gz
Source-MD5: 2f0eeb543cf15d616142eac0bd843cec
SourceDirectory: %n
PatchScript: sed 's|@FINKPREFIX@|%p|g' < %a/%n.patch | patch -p1
TarFilesRename: debconf/debconf$:debconf/debconf.tmp
UpdatePOD: true
CompileScript: echo "Nothing to see here..." && set -e && make

InstallScript: <<
#!/bin/sh -e

  export PERL5LIB=.

  mkdir -p %i/etc/apt/apt.conf.d
  cp debian/apt.conf %i/etc/apt/apt.conf.d/70debconf

  make install prefix=%i install-utils
  make install prefix=%i install-i18n
  make install prefix=%i install-rest

  # Ok, move debconf to it's correct name
  mv %i/bin/debconf.tmp %i/bin/debconf

  ln -s %p/sare/doc/%n %i/share/doc/%n-english
  ln -s %p/sare/doc/%n %i/share/doc/%n-i18n
  ln -s %p/sare/doc/%n %i/share/doc/%n-utils
  ln -s %p/sare/doc/%n %i/share/doc/%n-doc

  mkdir -p %d/DEBIAN
  cp debian/config debian/templates %d/DEBIAN
<<

Splitoff: <<
  Package: %N-english
  Conflicts: %N-i18n
  Replaces: %N-i18n
  Description: small footprint English-only debconf
  DescDetail: <<
    This package is an alternative to the debconf-i18n package, intended for 
systems that are administered only in English, and low-footprint systems. If 
you install this package, debconf will not work properly in other languages, 
but you'll save half a megabyte of disk space.
  <<
  Files: share/doc/%n
<<

Splitoff2: <<
  Package: %N-utils
  Conflicts: %N-i18n
  Replaces: %N-i18n
  Depends: debconf
  Description: debconf utilities
  DescDetail: <<
    This package contains some small utilities for debconf developers.
  <<
  Files: bin/debconf-[glm]* share/doc/%n share/man/man1/debconf-[glm]*
<<

Splitoff3: <<
  Package: %N-i18n
  Depends: locale-gettext-pm581 | locale-gettext-pm584 | text-iconv-pm581
  Description: full internationalization support for debconf
  DescDetail: <<
  This package provides full internationalization for debconf, including 
translations into all available languages, support for using translated debconf 
templates, and support for proper display of multibyte character sets.
  <<
  Files: share/doc/%n share/locale share/man/fr/man1 share/man/pt_BR/man1
<<

Splitoff4: <<
  Package: %N-doc
  Description: debconf documentation
  DescDetail: <<
    This package contains lots of additional documentation for Debconf, 
including the debconf user's guide, documentation about using different backend 
databases via the /etc/debconf.conf file, and a developer's guide to debconf.
  <<
  DocFiles: doc/README debian/README.Debian  debian/changelog
  InstallScript: <<
  #!/bin/sh -e
  mkdir -p %i/share/doc/%n
  cd doc
  cp CREDITS README.LDAP TODO namespace.txt EXAMPLES README.translators 
debconf.schema html.dsl passthrough.txt %i/share/doc/%n/
  <<
  Files: share/man/fr/man[357] share/man/man[357] share/man/pt_BR/man[357]
<<

DocFiles: doc/README debian/README.Debian  debian/changelog
Description: Package configuration management system
DescDetail: <<
  Debconf is a configuration management system for debian/fink packages. 
Packages use Debconf to ask questions when they are installed.
<<

# Fix up broken db's before debconf starts up.

PostInstScript: <<
  #!/bin/sh -e
  
  # configdb splits into passworded and non-passworded parts, before debconf
  # starts up. Do so only if the debconf.conf has the new databases in it.
  if [ -z "$DEBIAN_HAS_FRONTEND" -a "$1" = configure -a -n "$2" ] && \
     dpkg --compare-versions "$2" lt 1.1.0 &&
     perl -e 'use Debconf::Db; Debconf::Db->load; for (@ARGV) { exit 1 unless
              Debconf::DbDriver->driver($_) }' config passwords; then
          # copies in only the passwords, of course
          debconf-copydb config passwords
          # makes a new config with only non-passwords in it
          debconf-copydb config newconfig \
                -c Name:newconfig \
                -c Driver:File \
                -c Reject-Type:password \
                -c Filename:%p/var/cache/debconf/newconfig.dat \
                -c Mode:644
          mv -f %p/var/cache/debconf/newconfig.dat 
%p/var/cache/debconf/config.dat
  fi

  . %p/share/debconf/confmodule
<<

DescPort: <<
  grep -rl /usr/share . | grep -v "(prefx" | xargs perl -pi -e 
's|/usr/share|[EMAIL PROTECTED]@/share|g'
  grep -rl "\$(prefix)@FINKPREFIX@" . | xargs perl -pi -e 's|\$\(prefix\)[EMAIL 
PROTECTED]@|\$\(prefix\)|g'
  grep -r /usr . | grep -v perl  #### manually find more stuff
  perl -pi -e 's|\$\(prefix\)/usr|\$\(prefix\)|g' Makefile
  grep -rl /var . | xargs perl -pi -e 's|\ /var|\ [EMAIL PROTECTED]@/var|g'
  grep -r /var . | grep -v @FINK  #### manually catch stuff
<<
License: GPL
Maintainer: Chris Zubrzycki <[EMAIL PROTECTED]>
Homepage: http://packages.debian.org/unstable/admin/debconf.html

--- NEW FILE: tar.info ---
Package: tar
Version: 1.14
Revision: 2
Essential: yes
GCC: 3.3
Depends: libgettext3, gzip, bzip2, base-files
BuildDepends: libgettext3-dev
Source: mirror:sourceforge:fink/%n-%v.tar.gz
Source-MD5: 3094544702b1affa32d969f0b6459663 
UpdateConfigGuess: true
ConfigureParams: --program-transform-name=s/tar/gtar/ --infodir=%p/share/info 
--libexecdir=%p/lib
InstallScript: <<
 make install DESTDIR=%d
 cd %i/bin ; ln -s gtar tar ; ln -s gtar gnutar
<<
DocFiles: README* COPYING AUTHORS NEWS THANKS
#
PreInstScript: <<
if [ -L %p/etc/alternatives/rmt ]; then
  update-alternatives --remove rmt %p/lib/rmt-tar
  rm -f %p/lib/rmt
fi
<<
InfoDocs: tar.info
#
Description: GNU tar - tape archiver
DescPackaging: Previous versions by Christoph Pfisterer.
License: GPL
Maintainer: Fink Core Group <[EMAIL PROTECTED]>
Homepage: http://www.gnu.org/software/tar/

--- NEW FILE: dpkg.info ---
Package: dpkg
Version: 1.10.21
Revision: 204
GCC: 3.3
Depends: libgettext3, libiconv, gzip, tar, libncurses5-shlibs
BuildDepends: gcc3.3
Essential: yes
Maintainer: Fink Core Group <[EMAIL PROTECTED]>
Source: mirror:sourceforge:fink/dpkg_%v.tar.gz
SourceDirectory: %n-%v
Source-MD5: a9f6c43891db74d727beab7dfc0ee663
PatchScript: sed 's|@PREFIX@|%p|g' <%a/%n.patch | patch -p1
SetCFLAGS: -no-cpp-precomp -I%p/include
NoSetMAKEFLAGS: true
SetMAKEFLAGS: -j1
CompileScript: <<
 %p/bin/fink -y install gettext-bin libgettext3-dev libiconv-dev libncurses5
 export CC=gcc-3.3; export CXX=g++-3.3; PERL=/usr/bin/perl ./configure 
--build=%m-apple-darwin %c
 make EXEFLAGS=-force_flat_namespace CC=gcc-3.3 CXX=g++-3.3
<<
ConfigureParams: --without-start-stop-daemon --without-sgml-doc 
--with-admindir=%p/var/lib/dpkg --mandir=%p/share/man --infodir=%p/share/info 
--srcdir=%b
InstallScript: <<
 mkdir -p %i/share/doc/dpkg
 make install DESTDIR=%d
 install -c -p -m 644 origin.fink %i/etc/dpkg/origins/fink
 rm -rf %i/lib/dpkg/methods/*
<<
Description: The Debian package manager
DescDetail: <<
dpkg installs and removes binary packages; it is the base of the
distribution. This package also contains some helper programs and
dselect, a full-screen console frontend to dpkg.
<<
DescPort: <<
1.10.9 
- Removed --without-zlib flag
- Gets confused about top_srcdir without the --srcdir arg.
- Fixed bug with BR manpage
- Patched update-rc.d out of the app check code, not needed on OS X.

Pre-Jaguar: Needed fixes to use the right architecture, disable code that uses
unimplemented functions on Darwin and other stuff.

Added code to support the pseudo package 'macosx' and 'darwin'.

Fix to install-info script to prevent a certain problem with section titles.

Patched to run 'fink-virtual-pkgs' to see what packages we have outside of 
$prefix.

Patched to suppress warning about BuildDependsOnly control field.

Previous versions by Christoph Pfisterer.
<<
#
PostInstScript: <<
if [ ! -f %p/var/lib/dpkg/diversions ]; then
  touch %p/var/lib/dpkg/diversions
  chmod 644 %p/var/lib/dpkg/diversions
fi
<<
License: GPL
Homepage: http://packages.qa.debian.org/d/dpkg.html



-------------------------------------------------------
This SF.Net email is sponsored by: IntelliVIEW -- Interactive Reporting
Tool for open source databases. Create drag-&-drop reports. Save time
by over 75%! Publish reports on the web. Export to DOC, XLS, RTF, etc.
Download a FREE copy at http://www.intelliview.com/go/osdn_nl
_______________________________________________
Fink-commits mailing list
Fink-commits@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/fink-commits

Reply via email to
diff -ruN debconf-1.4.42/Debconf/Client/ConfModule.pm 
debconf-1.4.42.new/Debconf/Client/ConfModule.pm
--- debconf-1.4.42/Debconf/Client/ConfModule.pm Wed Nov  3 14:13:46 2004
+++ debconf-1.4.42.new/Debconf/Client/ConfModule.pm     Mon Jan 17 00:36:34 2005
@@ -71,14 +71,14 @@
 sub import {
        if (! $ENV{DEBIAN_HAS_FRONTEND}) {
                $ENV{PERL_DL_NONLAZY}=1;
-               exec "/usr/share/debconf/frontend", $0, @ARGV;
+               exec "@FINKPREFIX@/share/debconf/frontend", $0, @ARGV;
        }
 
        # Make the Exporter still work.
        Debconf::Client::ConfModule->export_to_level(1, @_);
 
        # A truely gross hack. This only is needed if
        # /usr/share/debconf/confmodule is loaded, and then this
        # perl module is used. In that case, this module needs to write
        # to fd #3, rather than stdout. See changelog 0.3.74.
[...1412 lines suppressed...]
 #!/bin/sh -e
 
 # Source debconf library.
-. /usr/share/debconf/confmodule
+. @FINKPREFIX@/share/debconf/confmodule
 db_version 2.0
 
 # This conf script is capable of backing up
@@ -71,14 +71,14 @@
 
        # A truely gross hack. This only is needed if
-       # /usr/share/debconf/confmodule is loaded, and then this
+       # @FINKPREFIX@/share/debconf/confmodule is loaded, and then this
        # perl module is used. In that case, this module needs to write
        # to fd #3, rather than stdout. See changelog 0.3.74.